# Introduction
This repo really isn't fit for public use :) Contact adam.p.zakaria@gmail.com if you're curious about what it's all about.

# Upload to Pypi
```
rm -rf dist/*
poetry build
twine upload dist/*
```